API Reference
=============

This page contains the API documentation for pys3local modules.

Core Modules
------------

.. toctree::
   :maxdepth: 4

   pys3local

pys3local package
-----------------

.. automodule:: pys3local
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

pys3local.auth module
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.auth
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.cli module
~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.cli
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.config module
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.config
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.constants module
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.constants
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.errors module
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.errors
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.models module
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.models
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.provider module
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.provider
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.server module
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.server
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.xml_templates module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.xml_templates
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

pys3local.providers package
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pys3local.providers
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.providers.local module
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pys3local.providers.local
   :members:
   :undoc-members:
   :show-inheritance:

pys3local.providers.drime module
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pys3local.providers.drime
   :members:
   :undoc-members:
   :show-inheritance:
